@@ -23,14 +23,14 @@ type ReplaceCommandArgs struct {
 	Search      string         `arg:"positional,required"`
 	Replacement string         `arg:"positional,required"`
 	Path        string         `arg:"positional"`
-	Confirm     bool           `arg:"-y,--confirm" help:"Write results without prompt"`
-	DryRun      bool           `arg:"-n,--dry-run" help:"Skip writing results without prompt"`
-	KeySelector string         `arg:"-s,--key-selector" help:"Limit replacements to specified key" placeholder:"PATTERN"`
-	Keys        bool           `arg:"-k,--keys" help:"Match against keys (true if -v is not specified)"`
-	Output      MatchOutputArg `arg:"-o,--output" help:"Present changes as 'inline' with color or traditional 'diff'" default:"inline"`
-	Regexp      bool           `arg:"-e,--regexp" help:"Treat search string and selector as a regexp"`
-	Shallow     bool           `arg:"-S,--shallow" help:"Only search leaf nodes of the path rather than recurse deeper"`
-	Values      bool           `arg:"-v,--values" help:"Match against values (true if -k is not specified)"`
+	Confirm     bool           `arg:"-y,--confirm"        help:"Write results without prompt"`
+	DryRun      bool           `arg:"-n,--dry-run"        help:"Skip writing results without prompt"`
+	KeySelector string         `arg:"-s,--key-selector"   help:"Limit replacements to specified key"                           placeholder:"PATTERN"`
+	Keys        bool           `arg:"-k,--keys"           help:"Match against keys (true if -v is not specified)"`
+	Output      MatchOutputArg `arg:"-o,--output"         help:"Present changes as 'inline' with color or traditional 'diff'"                        default:"inline"`
+	Regexp      bool           `arg:"-e,--regexp"         help:"Treat search string and selector as a regexp"`
+	Shallow     bool           `arg:"-S,--shallow"        help:"Only search leaf nodes of the path rather than recurse deeper"`
+	Values      bool           `arg:"-v,--values"         help:"Match against values (true if -k is not specified)"`
 }
 
 // Description provides detail on what the command does
@@ -88,16 +88,16 @@ func (cmd *ReplaceCommand) Parse(args []string) error {
 	if cmd.args.Path == "" {
 		cmd.args.Path = cmd.client.Pwd
 	}
-	if cmd.args.Keys == true {
+	if cmd.args.Keys {
 		cmd.Mode |= ModeKeys
 	}
-	if cmd.args.Values == true {
+	if cmd.args.Values {
 		cmd.Mode |= ModeValues
 	}
 	if cmd.Mode == 0 {
 		cmd.Mode = ModeKeys + ModeValues
 	}
-	if cmd.args.DryRun == true && cmd.args.Confirm == true {
+	if cmd.args.DryRun && cmd.args.Confirm {
 		cmd.args.Confirm = false
 	}
 
@@ -127,7 +127,9 @@ func (cmd *ReplaceCommand) Run() int {
 	return cmd.commitMatches(allMatches)
 }
 
-func (cmd *ReplaceCommand) findMatches(filePaths []string) (matchesByPath map[string][]*Match, err error) {
+func (cmd *ReplaceCommand) findMatches(
+	filePaths []string,
+) (matchesByPath map[string][]*Match, err error) {
 	matchesByPath = make(map[string][]*Match, 0)
 	for _, curPath := range filePaths {
 		matches, err := cmd.FindReplacements(cmd.args.Search, cmd.args.Replacement, curPath)
@@ -139,7 +141,7 @@ func (cmd *ReplaceCommand) findMatches(filePaths []string) (matchesByPath map[st
 		}
 		if len(matches) > 0 {
 			_, ok := matchesByPath[curPath]
-			if ok == false {
+			if !ok {
 				matchesByPath[curPath] = make([]*Match, 0)
 			}
 			matchesByPath[curPath] = append(matchesByPath[curPath], matches...)
@@ -150,19 +152,22 @@ func (cmd *ReplaceCommand) findMatches(filePaths []string) (matchesByPath map[st
 
 func (cmd *ReplaceCommand) commitMatches(matchesByPath map[string][]*Match) int {
 	if len(matchesByPath) > 0 {
-		if cmd.args.Confirm == false && cmd.args.DryRun == false {
+		if !cmd.args.Confirm && !cmd.args.DryRun {
 			result, err := askForConfirmation("Write changes to Vault?")
 			if err != nil {
 				return 1
 			}
 			cmd.args.Confirm = result
 		}
-		if cmd.args.Confirm == false {
+		if !cmd.args.Confirm {
 			fmt.Println("Skipping write.")
 			return 0
 		}
 		fmt.Println("Writing!")
-		cmd.WriteReplacements(matchesByPath)
+		err := cmd.WriteReplacements(matchesByPath)
+		if err != nil {
+			fmt.Printf("Error writing replacement %s", err)
+		}
 	} else {
 		fmt.Println("No matches found to replace.")
 	}
@@ -170,7 +175,11 @@ func (cmd *ReplaceCommand) commitMatches(matchesByPath map[string][]*Match) int
 }
 
 // FindReplacements will find the matches for a given search string to be replaced
-func (cmd *ReplaceCommand) FindReplacements(search string, replacement string, path string) (matches []*Match, err error) {
+func (cmd *ReplaceCommand) FindReplacements(
+	search string,
+	replacement string,
+	path string,
+) (matches []*Match, err error) {
 	if cmd.client.GetType(path) == client.LEAF {
 		secret, err := cmd.client.Read(path)
 		if err != nil {
