@@ -3,6 +3,7 @@ package client
 import (
 	"errors"
 	"fmt"
+	"os"
 	"path/filepath"
 	"strconv"
 	"strings"
@@ -50,6 +51,19 @@ func verifyClientPwd(client *Client) (*Client, error) {
 	return client, nil
 }
 
+func getMountOutput(path string, version int) (string, *api.MountOutput) {
+	if !strings.HasSuffix(path, "/") {
+		path = path + "/"
+	}
+	path = strings.TrimPrefix(path, "/")
+
+	return path, &api.MountOutput{
+		Type:        "kv",
+		Options:     map[string]string{"version": strconv.Itoa(version)},
+		Description: "KV version " + strconv.Itoa(version) + " mount",
+	}
+}
+
 // NewClient creates a new Client Vault wrapper
 func NewClient(conf *VaultConfig) (*Client, error) {
 	config := &api.Config{
@@ -57,10 +71,14 @@ func NewClient(conf *VaultConfig) (*Client, error) {
 	}
 
 	if len(conf.CertificatePath) > 0 {
-		log.UserDebug("Configuring TLS to be " + conf.CertificatePath)
-		config.ConfigureTLS(&api.TLSConfig{
+		log.UserDebug("Configuring TLS to be %s", conf.CertificatePath)
+		err := config.ConfigureTLS(&api.TLSConfig{
 			CAPath: conf.CertificatePath,
 		})
+		if err != nil {
+			fmt.Printf("Error configuring TLS: %v", err)
+			return nil, err
+		}
 	}
 
 	vault, err := api.NewClient(config)
@@ -72,13 +90,36 @@ func NewClient(conf *VaultConfig) (*Client, error) {
 
 	permissions, err := vault.Sys().CapabilitiesSelf("sys/mounts")
 
-	var mounts map[string]*api.MountOutput
+	mounts := make(map[string]*api.MountOutput)
 	if sliceContains(permissions, "list") || sliceContains(permissions, "root") {
 		mounts, err = vault.Sys().ListMounts()
 	} else {
 		log.UserDebug("Cannot auto-discover mount backends: Token does not have list permission on sys/mounts")
 	}
 
+	if os.Getenv("VAULT_KV1_MOUNTS") != "" {
+		for _, mount := range strings.Split(os.Getenv("VAULT_KV1_MOUNTS"), ",") {
+			path, mountOutput := getMountOutput(mount, 1)
+			mounts[path] = mountOutput
+		}
+	}
+
+	if os.Getenv("VAULT_KV2_MOUNTS") != "" {
+		for _, mount := range strings.Split(os.Getenv("VAULT_KV2_MOUNTS"), ",") {
+			path, mountOutput := getMountOutput(mount, 2)
+			mounts[path] = mountOutput
+		}
+	}
+
+	if len(mounts) == 0 {
+		log.UserDebug(
+			"No KV mounts found or specified, adding default KV version 2 mount at /secrets",
+		)
+
+		// Add default KV version 2 mount at /secrets
+		_, mounts["secrets/"] = getMountOutput("secrets/", 2)
+	}
+
 	if err != nil {
 		log.AppTrace("%+v", err)
 		return nil, err
@@ -186,7 +227,7 @@ func (client *Client) SubpathsForPath(path string, shallow bool) (filePaths []st
 			filePaths = append(filePaths, traversedPath)
 		}
 	default:
-		return filePaths, fmt.Errorf("Not a valid path for operation: %s", path)
+		return filePaths, fmt.Errorf("not a valid path for operation: %s", path)
 	}
 	return filePaths, nil
 }
